# Additional Tools

:::{warning}

`pycompwa` is no longer maintained. Use the
[ComPWA](https://compwa-org.rtfd.io) packages [QRules](https://qrules.rtfd.io),
[AmpForm](https://ampform.rtfd.io), and
[TensorWaves](https://tensorwaves.rtfd.io) instead!

:::

ComPWA provides additional tools for partial wave analysis that enrich the
usual {doc}`workflow`. The following pages illustrate how to use those tools.

```{toctree}
:glob: true
:maxdepth: 1

tools/*
```
